@@ -17,7 +17,7 @@ from .commands import (
     install_extension, uninstall_extension, list_extensions,
     enable_extension, disable_extension, check_extension,
     link_package, unlink_package, build, get_app_version, HERE,
-    update_extension,
+    update_extension, AppOptions,
 )
 from .coreconfig import CoreConfig
 from .debuglog import DebugLogFileMixin
@@ -99,10 +99,10 @@ class BaseExtensionApp(JupyterApp, DebugLogFileMixin):
                 if self.minimize:
                     parts.append('minimize')
                 command = ':'.join(parts)
-
-                build(app_dir=self.app_dir, clean_staging=self.should_clean,
-                      logger=self.log, command=command,
+                app_options = AppOptions(app_dir=self.app_dir, logger=self.log,
                       core_config=self.core_config)
+                build(clean_staging=self.should_clean,
+                      command=command, app_options=app_options)
 
     def run_task(self):
         pass
@@ -114,13 +114,13 @@ class BaseExtensionApp(JupyterApp, DebugLogFileMixin):
 
 class InstallLabExtensionApp(BaseExtensionApp):
     description = """Install labextension(s)
-    
+
      Usage
-    
+
         jupyter labextension install [--pin-version-as <alias,...>] <package...>
-    
+
     This installs JupyterLab extensions similar to yarn add or npm install.
-    
+
     Pass a list of comma seperate names to the --pin-version-as flag
     to use as alises for the packages providers. This is useful to
     install multiple versions of the same extension.
@@ -138,11 +138,13 @@ class InstallLabExtensionApp(BaseExtensionApp):
         return any([
             install_extension(
                 arg,
-                self.app_dir,
-                logger=self.log,
-                core_config=self.core_config,
                 # Pass in pinned alias if we have it
-                pin=pinned_versions[i] if i < len(pinned_versions) else None
+                pin=pinned_versions[i] if i < len(pinned_versions) else None,
+                app_options=AppOptions(
+                    app_dir=self.app_dir,
+                    logger=self.log,
+                    core_config=self.core_config,
+                )
             )
             for i, arg in enumerate(self.extra_args)
         ])
@@ -159,14 +161,12 @@ class UpdateLabExtensionApp(BaseExtensionApp):
         if not self.all and not self.extra_args:
             self.log.warn('Specify an extension to update, or use --all to update all extensions')
             return False
+        app_options = AppOptions(app_dir=self.app_dir, logger=self.log,
+            core_config=self.core_config)
         if self.all:
-            return update_extension(
-                all_=True, app_dir=self.app_dir, logger=self.log,
-                core_config=self.core_config)
+            return update_extension(all_=True, app_options=app_options)
         return any([
-            update_extension(
-                name=arg, app_dir=self.app_dir, logger=self.log,
-                core_config=self.core_config)
+            update_extension(name=arg, app_options=app_options)
             for arg in self.extra_args
         ])
 
@@ -184,10 +184,13 @@ class LinkLabExtensionApp(BaseExtensionApp):
 
     def run_task(self):
         self.extra_args = self.extra_args or [os.getcwd()]
+        options = AppOptions(
+            app_dir=self.app_dir, logger=self.log,
+            core_config=self.core_config)
         return any([
             link_package(
-                arg, self.app_dir, logger=self.log,
-                core_config=self.core_config)
+                arg,
+                app_options=options)
             for arg in self.extra_args
         ])
 
@@ -197,10 +200,13 @@ class UnlinkLabExtensionApp(BaseExtensionApp):
 
     def run_task(self):
         self.extra_args = self.extra_args or [os.getcwd()]
+        options = AppOptions(
+            app_dir=self.app_dir, logger=self.log,
+            core_config=self.core_config)
         return any([
             unlink_package(
-                arg, self.app_dir, logger=self.log,
-                core_config=self.core_config)
+                arg,
+                app_options=options)
             for arg in self.extra_args
         ])
 
@@ -214,10 +220,13 @@ class UninstallLabExtensionApp(BaseExtensionApp):
 
     def run_task(self):
         self.extra_args = self.extra_args or [os.getcwd()]
+        options = AppOptions(
+            app_dir=self.app_dir, logger=self.log,
+            core_config=self.core_config)
         return any([
             uninstall_extension(
-                arg, all_=self.all, app_dir=self.app_dir, logger=self.log,
-                core_config=self.core_config)
+                arg, all_=self.all,
+                app_options=options)
             for arg in self.extra_args
         ])
 
@@ -226,26 +235,26 @@ class ListLabExtensionsApp(BaseExtensionApp):
     description = "List the installed labextensions"
 
     def run_task(self):
-        list_extensions(
-            self.app_dir, logger=self.log, core_config=self.core_config)
+        list_extensions(app_options=AppOptions(
+            app_dir=self.app_dir, logger=self.log, core_config=self.core_config))
 
 
 class EnableLabExtensionsApp(BaseExtensionApp):
     description = "Enable labextension(s) by name"
 
     def run_task(self):
-        [enable_extension(
-            arg, self.app_dir, logger=self.log, core_config=self.core_config)
-         for arg in self.extra_args]
+        app_options = AppOptions(
+            app_dir=self.app_dir, logger=self.log, core_config=self.core_config)
+        [enable_extension(arg, app_options=app_options) for arg in self.extra_args]
 
 
 class DisableLabExtensionsApp(BaseExtensionApp):
     description = "Disable labextension(s) by name"
 
     def run_task(self):
-        [disable_extension(
-            arg, self.app_dir, logger=self.log, core_config=self.core_config)
-         for arg in self.extra_args]
+        app_options = AppOptions(
+            app_dir=self.app_dir, logger=self.log, core_config=self.core_config)
+        [disable_extension(arg, app_options=app_options) for arg in self.extra_args]
 
 
 class CheckLabExtensionsApp(BaseExtensionApp):
@@ -256,12 +265,13 @@ class CheckLabExtensionsApp(BaseExtensionApp):
         help="Whether it should check only if the extensions is installed")
 
     def run_task(self):
+        app_options = AppOptions(
+            app_dir=self.app_dir, logger=self.log, core_config=self.core_config)
         all_enabled = all(
             check_extension(
-                arg, self.app_dir,
-                self.should_check_installed_only,
-                logger=self.log,
-                core_config=self.core_config)
+                arg,
+                installed=self.should_check_installed_only,
+                app_options=app_options)
             for arg in self.extra_args)
         if not all_enabled:
             self.exit(1)
